@@ -21,8 +21,13 @@ def get_dataset(dataset=None):
     based on a user-provided label. In the future, we can add https endpoints
     to retrieve online datasets.
     """
+    dicom_cookies = os.path.join(data_base, "data", "dicom-cookies")
+
+    if not os.path.exists(dicom_cookies):
+        raise ValueError("install deid data with `pip install deid-data`")
+
     valid_datasets = {
-        "dicom-cookies": os.path.join(data_base, "data", "dicom-cookies"),
+        "dicom-cookies": dicom_cookies,
         "animals": os.path.join(data_base, "data", "animals"),
         "humans": os.path.join(data_base, "data", "humans"),
         "ultrasounds": os.path.join(data_base, "data", "ultrasounds"),
